Name:           mlpack
Version:        1.0.7
Release:        1%{?dist}
Summary:        Scalable, fast C++ machine learning library

Group:          System Environment/Libraries
License:        LGPLv3+
URL:            http://www.mlpack.org
Source0:        http://www.mlpack.org/files/%{name}-%{version}.tar.gz

# CMake by default doesn't provide support for specifying libdir on install
# (argh!) and this has to be done by hand in the CMake configuration.  This'll
# be fixed by mlpack 1.0.2.
Patch0:         cmake_libdir.patch

# By default the mlpack Doxyfile excludes all files in the directory pattern
# */build/*.  Well, on Koji, that's everything.  So we need to not exclude
# that.
Patch1:		no_exclude_build.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Use cmake28 package on RHEL.
%if 0%{?rhel}
BuildRequires:  cmake28 >= 2.8.5
%else
BuildRequires:  cmake >= 2.8.5
%endif

# 2.4.0 precipitated an internal Armadillo switch from 'u32' to 'uword' and the
# Armadillo extensions in mlpack depend on the use of 'uword' which is
# undefined <= 2.4.0.
BuildRequires:  armadillo-devel >= 3.6.0
BuildRequires:  libxml2-devel
BuildRequires:  boost-devel, boost-program-options, boost-math
BuildRequires:  lapack-devel
# For generating man pages (CMake configuration takes care of this assuming
# txt2man is installed).  It is possible that we could just add all the man
# pages, generated offline, as a patch to this SRPM, but txt2man seems to exist
# in repos.
BuildRequires:  txt2man
# For generation of Doxygen HTML documentation.
BuildRequires:  doxygen
BuildRequires:  graphviz

# something doesn't like size_t being unsigned long on s390
ExcludeArch:    s390

%description
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.

# Executables.
%package bin
Summary:        Command-line executables for mlpack (machine learning library)
Group:          Applications/Engineering
Requires:       %{name}%{_isa} = %{version}-%{release}

%description bin
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.  This package provides the command-line executables which run mlpack
methods and related documentation.

# Development headers.
%package devel
Summary:        Development headers for mlpack (C++ machine learning library)
Group:          System Environment/Libraries
Requires:       %{name} = %{version}-%{release}
Requires:       armadillo-devel >= 3.6.0
Requires:       boost-devel, boost-program-options, boost-math
Requires:       libxml2-devel
Requires:       lapack-devel

%description devel
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use. Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users. mlpack outperforms competing machine learning libraries by large
margins.  This package provides the headers to compile applications against
mlpack.



%package doc
Summary:        Doxygen documentation for mlpack (C++ machine learning library)
Group:          Documentation

%description doc
mlpack is a C++ machine learning library with emphasis on scalability, speed,
and ease-of-use.  Its aim is to make machine learning possible for novice users
by means of a simple, consistent API, while simultaneously exploiting C++
language features to provide maximum performance and maximum flexibility for
expert users.  mlpack outperforms competing machine learning libraries by large
margins.  This package provides the Doxygen-generated documentation for mlpack.

# For the F20 unversioned documentation change.  This evaluates to
# %{_pkgdocdir} if on F20 and %{_docdir}/%{name}-%{version} otherwise.
%global our_docdir %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}

%prep
%setup -q
%patch0 -p1
%patch1 -p1


%build
%if 0%{?rhel}
# On RHEL6, the Boost CMake scripts fail for some reason.  I don't have the
# time (or patience) to investigate, but if we force CMake to find Boost "the
# hard way" by specifying Boost_NO_BOOST_CMAKE=1, it works.
%{cmake28} -D Boost_NO_BOOST_CMAKE=1 -D LIBDIR=%{_libdir} -D DEBUG=OFF -D PROFILE=OFF .
%else
%{cmake} -D LIBDIR=%{_libdir} -D DEBUG=OFF -D PROFILE=OFF .
%endif

make %{?_smp_mflags}
# Build documentation ('doc' is not in the list of default targets).
make doc


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Put the license file and documentation in place.
if [ "%{our_docdir}" != "%{_docdir}/mlpack" ]; then
  mv $RPM_BUILD_ROOT/%{_docdir}/mlpack $RPM_BUILD_ROOT/%{our_docdir}
fi
mkdir -p $RPM_BUILD_ROOT/%{our_docdir}
cp LICENSE.txt $RPM_BUILD_ROOT/%{our_docdir}


# Rename executables to mlpack_* to avoid possible naming collisions.  Upstream
# bug report http://trac.research.cc.gatech.edu/fastlab/ticket/236.
for i in `ls $RPM_BUILD_ROOT/%{_bindir}`
do
  %{__mv} $RPM_BUILD_ROOT/%{_bindir}/$i $RPM_BUILD_ROOT/%{_bindir}/mlpack_$i;
done
for i in `ls $RPM_BUILD_ROOT/%{_mandir}/man1`
do
  %{__mv} $RPM_BUILD_ROOT/%{_mandir}/man1/$i $RPM_BUILD_ROOT/%{_mandir}/man1/mlpack_$i;
done

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%{_libdir}/libmlpack.so.1
%{_libdir}/libmlpack.so.1.0
%{our_docdir}/LICENSE.txt

%files bin
%defattr(-,root,root,-)
%{_bindir}/mlpack_allknn
%{_bindir}/mlpack_allkfn
%{_bindir}/mlpack_allkrann
%{_bindir}/mlpack_cf
%{_bindir}/mlpack_det
%{_bindir}/mlpack_emst
%{_bindir}/mlpack_fastmks
%{_bindir}/mlpack_gmm
%{_bindir}/mlpack_hmm_generate
%{_bindir}/mlpack_hmm_loglik
%{_bindir}/mlpack_hmm_train
%{_bindir}/mlpack_hmm_viterbi
%{_bindir}/mlpack_kernel_pca
%{_bindir}/mlpack_kmeans
%{_bindir}/mlpack_lars
%{_bindir}/mlpack_linear_regression
%{_bindir}/mlpack_local_coordinate_coding
%{_bindir}/mlpack_lsh
%{_bindir}/mlpack_nbc
%{_bindir}/mlpack_nca
%{_bindir}/mlpack_nmf
%{_bindir}/mlpack_pca
%{_bindir}/mlpack_radical
%{_bindir}/mlpack_range_search
%{_bindir}/mlpack_sparse_coding
%{_mandir}/man1/mlpack_allknn.1*
%{_mandir}/man1/mlpack_allkfn.1*
%{_mandir}/man1/mlpack_allkrann.1*
%{_mandir}/man1/mlpack_cf.1*
%{_mandir}/man1/mlpack_det.1*
%{_mandir}/man1/mlpack_emst.1*
%{_mandir}/man1/mlpack_fastmks.1*
%{_mandir}/man1/mlpack_gmm.1*
%{_mandir}/man1/mlpack_hmm_generate.1*
%{_mandir}/man1/mlpack_hmm_loglik.1*
%{_mandir}/man1/mlpack_hmm_train.1*
%{_mandir}/man1/mlpack_hmm_viterbi.1*
%{_mandir}/man1/mlpack_kernel_pca.1*
%{_mandir}/man1/mlpack_kmeans.1*
%{_mandir}/man1/mlpack_lars.1*
%{_mandir}/man1/mlpack_linear_regression.1*
%{_mandir}/man1/mlpack_local_coordinate_coding.1*
%{_mandir}/man1/mlpack_lsh.1*
%{_mandir}/man1/mlpack_nbc.1*
%{_mandir}/man1/mlpack_nca.1*
%{_mandir}/man1/mlpack_nmf.1*
%{_mandir}/man1/mlpack_pca.1*
%{_mandir}/man1/mlpack_radical.1*
%{_mandir}/man1/mlpack_range_search.1*
%{_mandir}/man1/mlpack_sparse_coding.1*

%files devel
%defattr(-,root,root,-)
%{_libdir}/libmlpack.so
%{_includedir}/mlpack/

%files doc
%defattr(-,root,root,-)
%{our_docdir}

%changelog
* Sun Nov 03 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.7-1
- Update to latest stable release.

* Tue Aug 06 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.6-6
- Add no_exclude_build.patch so that Koji builds don't exclude all the code from Doxygen.

* Tue Aug 06 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.6-5
- Require graphviz (dot) for generation of Doxygen graphs.

* Tue Aug 06 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.6-4
- Use %{our_docdir} for F20 change to unversioned documentation directory names.
- Do not package HTML documentation in main package.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jul 27 2013 pmachata@redhat.com - 1.0.6-2
- Rebuild for boost 1.54.0

* Thu Jun 13 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.6-1
- Update to latest stable release.

* Sat May 25 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.5-1
- Update to latest stable release.
- Add new executables that version 1.0.5 provides.

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.0.4-3
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 1.0.4-2
- Rebuild for Boost-1.53.0

* Fri Feb 08 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.4-1
- Update to latest stable release.
- Update dependencies to new minimum requirements.

* Wed Jan 02 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.3-4
- Use cmake28 in RHEL packages.

* Wed Jan 02 2013 Dan Horák <dan[at]danny.cz> - 1.0.3-3
- Exclude s390, something doesn't like size_t being unsigned long

* Tue Jan 01 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.3-2
- Add u64_s64.patch.
- Fix bogus dates in changelog.
- Add new executables and man pages to files list.

* Tue Jan 01 2013 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.3-1
- Update to version 1.0.3.
- Remove now-unnecessary packages.

* Wed Sep 26 2012 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.1-5
- Simplify LICENSE.txt installation.
- Install doxygen documentation.

* Sun Sep 16 2012 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.1-4
- Distribute LICENSE.txt.

* Sun Jul 29 2012 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.1-3
- Fix group names for packages.
- Comment patches more verbosely.
- Rename exectuables to mlpack_* to avoid possible naming conflicts.

* Sat Jul 21 2012 Sterling Lewis Peet <sterling.peet@gatech.edu> - 1.0.1-2
- Include GetKernelMatrix patch so that mlpack builds using fedora flags.

* Thu Mar 08 2012 Ryan Curtin <gth671b@mail.gatech.edu> - 1.0.1-1
- Initial packaging of mlpack.
